This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] gcc/*: Fix comment typos.


Hi,

Committed as obvious.

Kazu Hirata

2005-04-01  Kazu Hirata  <kazu@cs.umass.edu>

	* cgraphunit.c, dbxout.c, flow.c, gcse.c, gimplify.c,
	lambda-code.c, loop.c, machmode.def, mips-tfile.c,
	modulo-sched.c, passes.c, postreload-gcse.c, tree-eh.c,
	tree-ssa-ccp.c, varasm.c, config/frv/frv.c, config/frv/frv.h,
	config/frv/frv.md, config/i386/i386.c, config/i386/i386.h,
	config/i386/i386.md, config/rs6000/predicates.md,
	config/rs6000/rs6000.c, config/s390/fixdfdi.h,
	config/s390/s390.c, config/stormy16/stormy16.c,
	config/stormy16/stormy16.md, config/vax/vax.md: Fix comment
	typos.

Index: cgraphunit.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cgraphunit.c,v
retrieving revision 1.98
diff -u -d -p -r1.98 cgraphunit.c
--- cgraphunit.c	30 Mar 2005 22:27:42 -0000	1.98
+++ cgraphunit.c	1 Apr 2005 03:34:25 -0000
@@ -282,8 +282,8 @@ decide_is_function_needed (struct cgraph
   return false;
 }
 
-/* Walk the decls we marked as neccesary and see if they reference new variables
-   or functions and add them into the worklists.  */
+/* Walk the decls we marked as necessary and see if they reference new
+   variables or functions and add them into the worklists.  */
 static bool
 cgraph_varpool_analyze_pending_decls (void)
 {
@@ -307,10 +307,10 @@ cgraph_varpool_analyze_pending_decls (vo
 }
 
 /* Optimization of function bodies might've rendered some variables as
-   unnecesary so we want to avoid these from being compiled.
+   unnecessary so we want to avoid these from being compiled.
 
    This is done by prunning the queue and keeping only the variables that
-   really appear needed (ie thery are either externally visible or referenced
+   really appear needed (ie they are either externally visible or referenced
    by compiled function). Re-doing the reachability analysis on variables
    brings back the remaining variables referenced by these.  */
 static void
@@ -772,7 +772,7 @@ cgraph_finalize_compilation_unit (void)
 {
   struct cgraph_node *node;
   /* Keep track of already processed nodes when called multiple times for
-     intermodule optmization.  */
+     intermodule optimization.  */
   static struct cgraph_node *first_analyzed;
 
   finish_aliases_1 ();
Index: dbxout.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/dbxout.c,v
retrieving revision 1.224
diff -u -d -p -r1.224 dbxout.c
--- dbxout.c	31 Mar 2005 14:59:48 -0000	1.224
+++ dbxout.c	1 Apr 2005 03:34:29 -0000
@@ -2360,7 +2360,7 @@ dbxout_symbol (tree decl, int local ATTR
     DBXOUT_DECR_NESTING_AND_RETURN (0);
 
   /* If we are to generate only the symbols actually used then such
-     symbol nodees are flagged with TREE_USED.  Ignore any that
+     symbol nodes are flagged with TREE_USED.  Ignore any that
      aren't flaged as TREE_USED.  */
 
   if (flag_debug_only_used_symbols
Index: flow.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/flow.c,v
retrieving revision 1.622
diff -u -d -p -r1.622 flow.c
--- flow.c	11 Mar 2005 09:04:52 -0000	1.622
+++ flow.c	1 Apr 2005 03:34:33 -0000
@@ -273,7 +273,7 @@ static int ndead;
    (remember, we are walking backward).  This can be computed as current
    pbi->insn_num - reg_deaths[regno].
    At the end of processing each basic block, the remaining live registers
-   are inspected and liferanges are increased same way so liverange of global
+   are inspected and live ranges are increased same way so liverange of global
    registers are computed correctly.
   
    The array is maintained clear for dead registers, so it can be safely reused
Index: gcse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gcse.c,v
retrieving revision 1.337
diff -u -d -p -r1.337 gcse.c
--- gcse.c	11 Mar 2005 09:04:58 -0000	1.337
+++ gcse.c	1 Apr 2005 03:34:39 -0000
@@ -3260,7 +3260,7 @@ cprop (int alter_jumps)
    settle for the condition variable in the jump instruction being integral.
    We prefer to be able to record the value of a user variable, rather than
    the value of a temporary used in a condition.  This could be solved by
-   recording the value of *every* register scaned by canonicalize_condition,
+   recording the value of *every* register scanned by canonicalize_condition,
    but this would require some code reorganization.  */
 
 rtx
Index: gimplify.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gimplify.c,v
retrieving revision 2.121
diff -u -d -p -r2.121 gimplify.c
--- gimplify.c	31 Mar 2005 23:34:38 -0000	2.121
+++ gimplify.c	1 Apr 2005 03:34:44 -0000
@@ -4428,7 +4428,7 @@ gimplify_one_sizepos (tree *expr_p, tree
 {
   /* We don't do anything if the value isn't there, is constant, or contains
      A PLACEHOLDER_EXPR.  We also don't want to do anything if it's already
-     a VAR_DECL.  If it's a VAR_DECL from another function, the gimplfier
+     a VAR_DECL.  If it's a VAR_DECL from another function, the gimplifier
      will want to replace it with a new variable, but that will cause problems
      if this type is from outside the function.  It's OK to have that here.  */
   if (*expr_p == NULL_TREE || TREE_CONSTANT (*expr_p)
Index: lambda-code.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/lambda-code.c,v
retrieving revision 2.30
diff -u -d -p -r2.30 lambda-code.c
--- lambda-code.c	13 Mar 2005 15:54:15 -0000	2.30
+++ lambda-code.c	1 Apr 2005 03:34:46 -0000
@@ -489,7 +489,7 @@ lcm (int a, int b)
 }
 
 /* Perform Fourier-Motzkin elimination to calculate the bounds of the
-   auxillary nest.
+   auxiliary nest.
    Fourier-Motzkin is a way of reducing systems of linear inequalities so that
    it is easy to calculate the answer and bounds.
    A sketch of how it works:
@@ -800,7 +800,7 @@ lambda_compute_auxillary_space (lambda_l
 /* Compute the loop bounds for the target space, using the bounds of
    the auxiliary nest AUXILLARY_NEST, and the triangular matrix H.  
    The target space loop bounds are computed by multiplying the triangular
-   matrix H by the auxillary nest, to get the new loop bounds.  The sign of
+   matrix H by the auxiliary nest, to get the new loop bounds.  The sign of
    the loop steps (positive or negative) is then used to swap the bounds if
    the loop counts downwards.
    Return the target loopnest.  */
@@ -1057,8 +1057,8 @@ lambda_compute_step_signs (lambda_trans_
    2. Composing the dense base with the specified transformation (TRANS)
    3. Decomposing the combined transformation into a lower triangular portion,
    and a unimodular portion. 
-   4. Computing the auxillary nest using the unimodular portion.
-   5. Computing the target nest using the auxillary nest and the lower
+   4. Computing the auxiliary nest using the unimodular portion.
+   5. Computing the target nest using the auxiliary nest and the lower
    triangular portion.  */ 
 
 lambda_loopnest
Index: loop.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/loop.c,v
retrieving revision 1.522
diff -u -d -p -r1.522 loop.c
--- loop.c	17 Jan 2005 08:46:15 -0000	1.522
+++ loop.c	1 Apr 2005 03:34:57 -0000
@@ -8904,7 +8904,7 @@ combine_givs (struct loop_regs *regs, st
       /* If a DEST_REG GIV is used only once, do not allow it to combine
 	 with anything, for in doing so we will gain nothing that cannot
 	 be had by simply letting the GIV with which we would have combined
-	 to be reduced on its own.  The losage shows up in particular with
+	 to be reduced on its own.  The lossage shows up in particular with
 	 DEST_ADDR targets on hosts with reg+reg addressing, though it can
 	 be seen elsewhere as well.  */
       if (g1->giv_type == DEST_REG
Index: machmode.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/machmode.def,v
retrieving revision 1.29
diff -u -d -p -r1.29 machmode.def
--- machmode.def	15 Oct 2004 14:47:09 -0000	1.29
+++ machmode.def	1 Apr 2005 03:34:58 -0000
@@ -41,7 +41,7 @@ Software Foundation, 59 Temple Place - S
 
    A CLASS argument must be one of the constants defined in
    mode-classes.def, less the leading MODE_ prefix; some statements
-   that take CLASS arguments have restructions on which classes are
+   that take CLASS arguments have restrictions on which classes are
    acceptable.  For instance, INT.
 
    A MODE argument must be the printable name of a machine mode,
Index: mips-tfile.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/mips-tfile.c,v
retrieving revision 1.65
diff -u -d -p -r1.65 mips-tfile.c
--- mips-tfile.c	10 Sep 2004 15:09:38 -0000	1.65
+++ mips-tfile.c	1 Apr 2005 03:35:02 -0000
@@ -1746,7 +1746,7 @@ add_string (varray_t *vp, shash_t **hash
 
 
 /* Add a local symbol.  The symbol string starts at STR_START and the
-   first byte after it is makred by STR_END_P1.  The symbol has type
+   first byte after it is marked by STR_END_P1.  The symbol has type
    TYPE and storage class STORAGE and value VALUE.  INDX is an index
    to local/aux. symbols.  */
 
Index: modulo-sched.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/modulo-sched.c,v
retrieving revision 1.23
diff -u -d -p -r1.23 modulo-sched.c
--- modulo-sched.c	21 Mar 2005 18:49:23 -0000	1.23
+++ modulo-sched.c	1 Apr 2005 03:35:04 -0000
@@ -455,7 +455,7 @@ calculate_maxii (ddg_ptr g)
    true-dependence of distance 1): SCHED_TIME (def) < SCHED_TIME (use) and
    if so generate a register move.   The number of such moves is equal to:
               SCHED_TIME (use) - SCHED_TIME (def)       { 0 broken
-   nreg_moves = ----------------------------------- + 1 - {   dependecnce.
+   nreg_moves = ----------------------------------- + 1 - {   dependence.
                             ii                          { 1 if not.
 */
 static void
Index: passes.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/passes.c,v
retrieving revision 2.78
diff -u -d -p -r2.78 passes.c
--- passes.c	31 Mar 2005 14:59:51 -0000	2.78
+++ passes.c	1 Apr 2005 03:35:06 -0000
@@ -252,7 +252,7 @@ rest_of_decl_compilation (tree decl,
       timevar_pop (TV_SYMOUT);
     }
 
-  /* Let cgraph know about the existance of variables.  */
+  /* Let cgraph know about the existence of variables.  */
   if (TREE_CODE (decl) == VAR_DECL && !DECL_EXTERNAL (decl))
     cgraph_varpool_node (decl);
 }
Index: postreload-gcse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/postreload-gcse.c,v
retrieving revision 2.10
diff -u -d -p -r2.10 postreload-gcse.c
--- postreload-gcse.c	31 Mar 2005 16:38:24 -0000	2.10
+++ postreload-gcse.c	1 Apr 2005 03:35:07 -0000
@@ -300,7 +300,7 @@ hash_expr_for_htab (const void *expp)
   return exp->hash;
 }
 
-/* Callbach for hashtab.
+/* Callback for hashtab.
    Return nonzero if exp1 is equivalent to exp2.  */
 
 static int
Index: tree-eh.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-eh.c,v
retrieving revision 2.27
diff -u -d -p -r2.27 tree-eh.c
--- tree-eh.c	9 Mar 2005 11:31:51 -0000	2.27
+++ tree-eh.c	1 Apr 2005 03:35:09 -0000
@@ -50,7 +50,7 @@ using_eh_for_cleanups (void)
 /* Misc functions used in this file.  */
 
 /* Compare and hash for any structure which begins with a canonical
-   pointer.  Assumes all pointers are interchangable, which is sort
+   pointer.  Assumes all pointers are interchangeable, which is sort
    of already assumed by gcc elsewhere IIRC.  */
 
 static int
Index: tree-ssa-ccp.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-ssa-ccp.c,v
retrieving revision 2.60
diff -u -d -p -r2.60 tree-ssa-ccp.c
--- tree-ssa-ccp.c	21 Mar 2005 14:35:07 -0000	2.60
+++ tree-ssa-ccp.c	1 Apr 2005 03:35:11 -0000
@@ -1582,7 +1582,7 @@ maybe_fold_stmt_indirect (tree expr, tre
       /* We can get here for out-of-range string constant accesses, 
 	 such as "_"[3].  Bail out of the entire substitution search
 	 and arrange for the entire statement to be replaced by a
-	 call to __builtin_trap.  In all likelyhood this will all be
+	 call to __builtin_trap.  In all likelihood this will all be
 	 constant-folded away, but in the meantime we can't leave with
 	 something that get_expr_operands can't understand.  */
 
Index: varasm.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/varasm.c,v
retrieving revision 1.491
diff -u -d -p -r1.491 varasm.c
--- varasm.c	31 Mar 2005 14:59:52 -0000	1.491
+++ varasm.c	1 Apr 2005 03:35:15 -0000
@@ -4421,7 +4421,7 @@ globalize_decl (tree decl)
 
 /* We have to be able to tell cgraph about the needed-ness of the target
    of an alias.  This requires that the decl have been defined.  Aliases
-   that preceed their definition have to be queued for later processing.  */
+   that precede their definition have to be queued for later processing.  */
 
 struct alias_pair GTY(())
 {
Index: config/frv/frv.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/frv/frv.c,v
retrieving revision 1.85
diff -u -d -p -r1.85 frv.c
--- config/frv/frv.c	22 Mar 2005 19:19:17 -0000	1.85
+++ config/frv/frv.c	1 Apr 2005 03:35:24 -0000
@@ -781,7 +781,7 @@ frv_override_options (void)
 
    You should not use this macro to change options that are not
    machine-specific.  These should uniformly selected by the same optimization
-   level on all supported machines.  Use this macro to enable machbine-specific
+   level on all supported machines.  Use this macro to enable machine-specific
    optimizations.
 
    *Do not examine `write_symbols' in this macro!* The debugging options are
Index: config/frv/frv.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/frv/frv.h,v
retrieving revision 1.60
diff -u -d -p -r1.60 frv.h
--- config/frv/frv.h	22 Mar 2005 19:19:18 -0000	1.60
+++ config/frv/frv.h	1 Apr 2005 03:35:27 -0000
@@ -351,7 +351,7 @@
 
    You should not use this macro to change options that are not
    machine-specific.  These should uniformly selected by the same optimization
-   level on all supported machines.  Use this macro to enable machbine-specific
+   level on all supported machines.  Use this macro to enable machine-specific
    optimizations.
 
    *Do not examine `write_symbols' in this macro!* The debugging options are
Index: config/frv/frv.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/frv/frv.md,v
retrieving revision 1.31
diff -u -d -p -r1.31 frv.md
--- config/frv/frv.md	7 Feb 2005 08:06:29 -0000	1.31
+++ config/frv/frv.md	1 Apr 2005 03:35:34 -0000
@@ -1206,7 +1206,7 @@
        (eq_attr "type" "sqrt_single"))
   "(f1|f0) + fr550_float")
 
-;; Synthetic units for enforcing media issue restructions.  Certain types
+;; Synthetic units for enforcing media issue restrictions.  Certain types
 ;; of insn in M2 conflict with certain types in M0:
 ;;
 ;;			     M2
@@ -5913,7 +5913,7 @@
 ;; Called after register allocation to add any instructions needed for the
 ;; epilogue.  Using an epilogue insn is favored compared to putting all of the
 ;; instructions in the FUNCTION_EPILOGUE macro, since it allows the scheduler
-;; to intermix instructions with the restires of the caller saved registers.
+;; to intermix instructions with the restores of the caller saved registers.
 ;; In some cases, it might be necessary to emit a barrier instruction as the
 ;; first insn to prevent such scheduling.
 (define_expand "epilogue"
Index: config/i386/i386.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/i386/i386.h,v
retrieving revision 1.423
diff -u -d -p -r1.423 i386.h
--- config/i386/i386.h	15 Mar 2005 14:44:09 -0000	1.423
+++ config/i386/i386.h	1 Apr 2005 03:35:52 -0000
@@ -1183,7 +1183,7 @@ do {									\
    This is computed in `reload', in reload1.c.  */
 #define FRAME_POINTER_REQUIRED  ix86_frame_pointer_required ()
 
-/* Override this in other tm.h files to cope with various OS losage
+/* Override this in other tm.h files to cope with various OS lossage
    requiring a frame pointer.  */
 #ifndef SUBTARGET_FRAME_POINTER_REQUIRED
 #define SUBTARGET_FRAME_POINTER_REQUIRED 0
Index: config/i386/i386.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/i386/i386.md,v
retrieving revision 1.621
diff -u -d -p -r1.621 i386.md
--- config/i386/i386.md	29 Mar 2005 05:46:46 -0000	1.621
+++ config/i386/i386.md	1 Apr 2005 03:36:11 -0000
@@ -19357,7 +19357,7 @@
     abort ();
 
   /* Use 3dNOW prefetch in case we are asking for write prefetch not
-     suported by SSE counterpart or the SSE prefetch is not available
+     supported by SSE counterpart or the SSE prefetch is not available
      (K6 machines).  Otherwise use SSE prefetch as it allows specifying
      of locality.  */
   if (TARGET_3DNOW && (!TARGET_PREFETCH_SSE || rw))
Index: config/rs6000/predicates.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/rs6000/predicates.md,v
retrieving revision 1.8
diff -u -d -p -r1.8 predicates.md
--- config/rs6000/predicates.md	24 Mar 2005 23:07:35 -0000	1.8
+++ config/rs6000/predicates.md	1 Apr 2005 03:36:12 -0000
@@ -593,7 +593,7 @@
   (match_code "symbol_ref,const,label_ref"))
 
 ;; Return 1 if op is a simple reference that can be loaded via the GOT,
-;; exclusing labels involving addition.
+;; excluding labels involving addition.
 (define_predicate "got_no_const_operand"
   (match_code "symbol_ref,label_ref"))
 
Index: config/rs6000/rs6000.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/rs6000/rs6000.c,v
retrieving revision 1.801
diff -u -d -p -r1.801 rs6000.c
--- config/rs6000/rs6000.c	31 Mar 2005 11:32:58 -0000	1.801
+++ config/rs6000/rs6000.c	1 Apr 2005 03:36:29 -0000
@@ -227,7 +227,7 @@ const char *rs6000_debug_name;
 int rs6000_debug_stack;		/* debug stack applications */
 int rs6000_debug_arg;		/* debug argument handling */
 
-/* Value is TRUE if register/mode pair is accepatable.  */
+/* Value is TRUE if register/mode pair is acceptable.  */
 bool rs6000_hard_regno_mode_ok_p[NUM_MACHINE_MODES][FIRST_PSEUDO_REGISTER];
 
 /* Opaque types.  */
@@ -15249,7 +15249,7 @@ static bool
 rs6000_is_costly_dependence (rtx insn, rtx next, rtx link, int cost,
 			     int distance)
 {
-  /* If the flag is not enbled - no dependence is considered costly;
+  /* If the flag is not enabled - no dependence is considered costly;
      allow all dependent insns in the same group.
      This is the most aggressive option.  */
   if (rs6000_sched_costly_dep == no_dep_costly)
Index: config/s390/fixdfdi.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/s390/fixdfdi.h,v
retrieving revision 1.4
diff -u -d -p -r1.4 fixdfdi.h
--- config/s390/fixdfdi.h	4 Jul 2003 22:28:57 -0000	1.4
+++ config/s390/fixdfdi.h	1 Apr 2005 03:36:29 -0000
@@ -55,7 +55,7 @@ __fixunsdfdi (double a1)
 
     dl1.d = a1;
 
-    /* +/- 0, denormalized, negativ */
+    /* +/- 0, denormalized, negative */
 
     if (!EXPD (dl1) || SIGND(dl1))
       return 0;
@@ -199,7 +199,7 @@ __fixunssfdi (float a1)
 
     fl1.f = a1;
 
-    /* +/- 0, denormalized, negativ */
+    /* +/- 0, denormalized, negative */
 
     if (!EXP (fl1) || SIGN(fl1))
       return 0;
Index: config/s390/s390.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/s390/s390.c,v
retrieving revision 1.219
diff -u -d -p -r1.219 s390.c
--- config/s390/s390.c	15 Mar 2005 15:46:52 -0000	1.219
+++ config/s390/s390.c	1 Apr 2005 03:36:37 -0000
@@ -4130,7 +4130,7 @@ s390_output_dwarf_dtprel (FILE *file, in
 }
 
 /* In the name of slightly smaller debug output, and to cater to
-   general assembler losage, recognize various UNSPEC sequences
+   general assembler lossage, recognize various UNSPEC sequences
    and turn them back into a direct symbol reference.  */
 
 static rtx
Index: config/stormy16/stormy16.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/stormy16/stormy16.c,v
retrieving revision 1.71
diff -u -d -p -r1.71 stormy16.c
--- config/stormy16/stormy16.c	31 Mar 2005 14:59:58 -0000	1.71
+++ config/stormy16/stormy16.c	1 Apr 2005 03:36:40 -0000
@@ -2658,7 +2658,7 @@ combine_bnp (rtx insn)
 
       if (and)
 	{
-	  /* Some mis-optimisations by GCC can generate a RIGHT-SHIFT
+	  /* Some mis-optimizations by GCC can generate a RIGHT-SHIFT
 	     followed by an AND like this:
 
                (parallel [(set (reg:HI r7) (lshiftrt:HI (reg:HI r7) (const_int 3)))
Index: config/stormy16/stormy16.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/stormy16/stormy16.md,v
retrieving revision 1.18
diff -u -d -p -r1.18 stormy16.md
--- config/stormy16/stormy16.md	3 Dec 2004 19:06:02 -0000	1.18
+++ config/stormy16/stormy16.md	1 Apr 2005 03:36:41 -0000
@@ -1104,7 +1104,7 @@
 ;; the epilogue.  Using an epilogue insn is favored compared to putting
 ;; all of the instructions in the TARGET_ASM_FUNCTION_EPILOGUE macro,
 ;; since it allows the scheduler to intermix instructions with the
-;; restires of the caller saved registers.  In some cases, it might be
+;; restores of the caller saved registers.  In some cases, it might be
 ;; necessary to emit a barrier instruction as the first insn to
 ;; prevent such scheduling.
 (define_expand "epilogue"
Index: config/vax/vax.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/vax/vax.md,v
retrieving revision 1.30
diff -u -d -p -r1.30 vax.md
--- config/vax/vax.md	27 Mar 2005 10:48:27 -0000	1.30
+++ config/vax/vax.md	1 Apr 2005 03:36:43 -0000
@@ -37,7 +37,7 @@
   ]
 )
 
-;; Integer modes supported on VAX, withd a mapping from machine mode
+;; Integer modes supported on VAX, with a mapping from machine mode
 ;; to mnemonic suffix.  DImode is always a special case.
 (define_mode_macro VAXint [QI HI SI])
 (define_mode_attr  isfx [(QI "b") (HI "w") (SI "l")])


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: config/i386/i386.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/i386/i386.c,v
retrieving revision 1.801
diff -u -d -p -r1.801 i386.c
--- config/i386/i386.c	30 Mar 2005 22:27:47 -0000	1.801
+++ config/i386/i386.c	1 Apr 2005 03:35:48 -0000
@@ -4112,7 +4112,7 @@ ix86_compute_frame_layout (struct ix86_f
 
   /* During reload iteration the amount of registers saved can change.
      Recompute the value as needed.  Do not recompute when amount of registers
-     didn't change as reload does mutiple calls to the function and does not
+     didn't change as reload does multiple calls to the function and does not
      expect the decision to change within single iteration.  */
   if (!optimize_size
       && cfun->machine->use_fast_prologue_epilogue_nregs != frame->nregs)
@@ -6030,7 +6030,7 @@ i386_output_dwarf_dtprel (FILE *file, in
 }
 
 /* In the name of slightly smaller debug output, and to cater to
-   general assembler losage, recognize PIC+GOTOFF and turn it back
+   general assembler lossage, recognize PIC+GOTOFF and turn it back
    into a direct symbol reference.  */
 
 static rtx
@@ -6137,8 +6137,8 @@ put_condition_code (enum rtx_code code, 
       suffix = "g";
       break;
     case GTU:
-      /* ??? Use "nbe" instead of "a" for fcmov losage on some assemblers.
-	 Those same assemblers have the same but opposite losage on cmov.  */
+      /* ??? Use "nbe" instead of "a" for fcmov lossage on some assemblers.
+	 Those same assemblers have the same but opposite lossage on cmov.  */
       if (mode != CCmode)
 	abort ();
       suffix = fp ? "nbe" : "a";